=======================
Calibration of Material
=======================

The calibration commands are used for material calibration.


Create material calibrations
----------------------------

.. autoclass:: abaqus.Calibration.CalibrationModel.CalibrationModel
    :members:
    :special-members: __init__

    .. autoclasstoc::


Classes
-------

Calibration
~~~~~~~~~~~

.. autoclass:: abaqus.Calibration.Calibration.Calibration
    :members:
    :special-members: __init__

    .. autoclasstoc::

Behavior
~~~~~~~~

.. autoclass:: abaqus.Calibration.Behavior.Behavior
    :members:
    :special-members: __init__

    .. autoclasstoc::

DataSet
~~~~~~~

.. autoclass:: abaqus.Calibration.DataSet.DataSet
    :members:
    :special-members: __init__

    .. autoclasstoc::
